Package superseded
==================


Package superseded
~~~~~~~~~~~~~~~~~~

This package has been superseded. The `dtw-python <https://pypi.org/project/dtw-python>`__ package should used instead.



Description
~~~~~~~~~~~


Comprehensive implementation of Dynamic Time Warping algorithms.
Supports arbitrary local (eg symmetric, asymmetric, slope-limited) and
global (windowing) constraints, fast native code, several plot styles,
and more.

This package provides
the most complete, freely-available (GPL) implementation of Dynamic Time
Warping-type (DTW) algorithms up to date. It is a faithful Python equivalent
of `R's DTW package <http://dtw.r-forge.r-project.org/>`__.


The package is described in a `companion
paper <http://www.jstatsoft.org/v31/i07/>`__, including detailed
instructions and extensive background on things like multivariate
matching, open-end variants for real-time use, interplay between
recursion types and length normalization, history, etc.

The project's homepage is <https://DynamicTimeWarping.github.io>
